@@ -17,9 +17,8 @@ import os
 import re
 import sys
 import copy
-from utils import uuid
 from utils.XY import XY
-from utils import urlutil
+from utils import images, urlutil, uuid
 import noderenderer
 
 
@@ -99,7 +98,7 @@ class Element(Base):
         self.group = None
         self.drawable = False
         self.order = 0
-        self.color = self.__class__.basecolor
+        self.color = self.basecolor
         self.width = 1
         self.height = 1
         self.stacked = False
@@ -117,13 +116,7 @@ class Element(Base):
         return format % locals()
 
     def set_color(self, color):
-        import webcolors
-        if color == 'none' or isinstance(color, (list, tuple)):
-            self.color = color
-        elif re.match('#', color):
-            self.color = webcolors.hex_to_rgb(color)
-        else:
-            self.color = webcolors.name_to_rgb(color)
+        self.color = images.color_to_rgb(color)
 
 
 class DiagramNode(Element):
@@ -134,16 +127,22 @@ class DiagramNode(Element):
     def set_default_shape(cls, shape):
         cls.default_shape = shape
 
+    @classmethod
+    def set_default_color(cls, color):
+        cls.basecolor = images.color_to_rgb(color)
+
     @classmethod
     def clear(cls):
-        cls.namespace = {}
+        super(DiagramNode, cls).clear()
         cls.default_shape = 'box'
+        cls.basecolor = (255, 255, 255)
 
     def __init__(self, id):
         super(DiagramNode, self).__init__(id)
 
         self.label = unquote(id) or ''
         self.shape = DiagramNode.default_shape
+        self.color = DiagramNode.basecolor
         self.style = None
         self.numbered = None
         self.icon = None
@@ -187,6 +186,15 @@ class DiagramNode(Element):
 class NodeGroup(Element):
     basecolor = (243, 152, 0)
 
+    @classmethod
+    def set_default_color(cls, color):
+        cls.basecolor = images.color_to_rgb(color)
+
+    @classmethod
+    def clear(cls):
+        super(NodeGroup, cls).clear()
+        cls.basecolor = (243, 152, 0)
+
     def __init__(self, id):
         super(NodeGroup, self).__init__(id)
 
@@ -194,6 +202,7 @@ class NodeGroup(Element):
         self.level = 0
         self.separated = False
         self.shape = 'box'
+        self.color = NodeGroup.basecolor
         self.nodes = []
         self.edges = []
         self.orientation = 'landscape'
@@ -273,9 +282,15 @@ class NodeGroup(Element):
 
 
 class Diagram(NodeGroup):
+    linecolor = (0, 0, 0)
     int_attrs = ['width', 'height', 'fontsize',
                  'node_width', 'node_height', 'span_width', 'span_height']
 
+    @classmethod
+    def clear(cls):
+        super(NodeGroup, cls).clear()
+        cls.linecolor = (0, 0, 0)
+
     def __init__(self):
         super(Diagram, self).__init__(None)
 
@@ -295,6 +310,18 @@ class Diagram(NodeGroup):
             msg = "WARNING: unknown node shape: %s\n" % value
             raise RuntimeError(msg)
 
+    def set_default_node_color(self, color):
+        color = images.color_to_rgb(color)
+        DiagramNode.set_default_color(color)
+
+    def set_default_line_color(self, color):
+        self.linecolor = images.color_to_rgb(color)
+        DiagramEdge.set_default_color(color)
+
+    def set_default_group_color(self, color):
+        color = images.color_to_rgb(color)
+        NodeGroup.set_default_color(color)
+
     def set_shape_namespace(self, value):
         noderenderer.set_default_namespace(value)
 
@@ -311,6 +338,7 @@ class Diagram(NodeGroup):
 
 
 class DiagramEdge(Base):
+    basecolor = (0, 0, 0)
     namespace = {}
 
     @classmethod
@@ -382,9 +410,14 @@ class DiagramEdge(Base):
 
         return edges
 
+    @classmethod
+    def set_default_color(cls, color):
+        cls.basecolor = images.color_to_rgb(color)
+
     @classmethod
     def clear(cls):
         cls.namespace = {}
+        cls.basecolor = (0, 0, 0)
 
     def __init__(self, node1, node2):
         self.node1 = node1
@@ -394,7 +427,7 @@ class DiagramEdge(Base):
 
         self.label = None
         self.dir = 'forward'
-        self.color = None
+        self.color = DiagramEdge.basecolor
         self.style = None
         self.hstyle = None
         self.folded = None
@@ -427,6 +460,9 @@ class DiagramEdge(Base):
             msg = "WARNING: unknown edge dir: %s\n" % value
             sys.stderr.write(msg)
 
+    def set_color(self, color):
+        self.color = images.color_to_rgb(color)
+
     def set_style(self, value):
         value = value.lower()
         if value in ('none', 'solid', 'dotted', 'dashed'):
